%define	major		10
%define	oname		nice
%define	libname		%mklibname %{oname} %major
%define develname	%mklibname %{oname} -d

Name:		libnice
Version:	0.1.4
Release:	%mkrel 2
Summary:	Implementation of the IETF's draft Interactive Connectivity Establishment standard
License:	LGPLv2+ and MPLv1+
Group:		System/Libraries
URL:		http://nice.freedesktop.org/wiki/
Source0:	http://nice.freedesktop.org/releases/%{name}-%{version}.tar.gz
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gobject-2.0)
BuildRequires:	pkgconfig(gthread-2.0)
BuildRequires:	pkgconfig(gio-2.0)
BuildRequires:	pkgconfig(gupnp-igd-1.0)
BuildRequires:	pkgconfig(gstreamer-1.0)
BuildRequires:	pkgconfig(gstreamer-0.10)

%description
Nice is an implementation of the IETF's draft Interactive Connectivity
Establishment standard (ICE). It provides GLib-based library, libnice.

ICE is useful for applications that want to establish peer-to-peer UDP
data streams. It automates the process of traversing NATs and provides
security against some attacks.

Existing standards that use ICE include the Session Initiation Protocol
(SIP) and Jingle, XMPP extension for audio/video calls.

Nice includes integration with GStreamer.

%package -n %{libname}
Summary:	Dynamic libraries from %{oname}
Group:		System/Libraries
Obsoletes:	%{_lib}nice1 < 0.1.1-4

%description -n	%{libname}
Dynamic libraries from %{name}.

%package -n %{develname}
Summary: 	Header files, libraries and development documentation for %{oname}
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{oname}-devel = %{version}-%{release}
Provides:       lib%{oname}-devel = %{version}-%{release}

%description -n	%{develname}
This package contains the development files, headers and documentation for
%{oname}.

%package utils
Summary:	Utilities from %{oname}
Group:		Networking/Other

%description utils
This package contains various tools from %{name}.

%package examples
Summary:	Example binaries for %{oname}
Group:		Networking/Other

%description examples
This package contains the example binaries for %{oname}.

%package -n gstreamer1.0-%{oname}
Summary:	Gstreamer elements from %{oname}
Group:		System/Libraries

%description -n gstreamer1.0-%{oname}
Gstreamer 1.0 elements from %{oname}.

%package -n gstreamer0.10-%{oname}
Summary:	Gstreamer elements from %{oname}
Group:		System/Libraries
# conflict with older %%libname that had the gst .so, before the split
Conflicts:	%{_lib}nice0 < 0.1.0
Conflicts:	%{_lib}nice1 < 0.1.0

%description -n	gstreamer0.10-%{oname}
Gstreamer 0.10 elements from %{oname}.

%prep
%setup -q
%apply_patches

%build
#autoreconf -fiv
%configure2_5x \
	--with-gstreamer \
	--with-gstreamer-0.10 \
	--enable-gupnp \
	--disable-static

# disable rpath
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make

%install
%makeinstall_std

# don't ship .la
find %{buildroot} -name "*.la" -delete

%check
%ifarch %arm
# test-new-dribble is failing on arm . Looks like it's racy
# disabling testsuite is bad :(
make check || %{_bindir}/true
%else
make check || %{_bindir}/true
%endif

%files -n %{libname}
%{_libdir}/*.so.%{major}*

%files -n %{develname}
%doc AUTHORS COPYING COPYING.LGPL COPYING.MPL NEWS README
%doc %{_datadir}/gtk-doc/html/%{name}/
%{_includedir}/%{oname}/
%{_includedir}/stun/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{oname}.pc

%files utils
%{_bindir}/stun*

%files examples
%{_bindir}/*-example

%files -n gstreamer1.0-%{oname}
%{_libdir}/gstreamer-1.0/libgstnice.so

%files -n gstreamer0.10-%{oname}
%{_libdir}/gstreamer-0.10/libgstnice010.so


%changelog
* Sat Oct 19 2013 umeabot <umeabot> 0.1.4-2.mga4
+ Revision: 525257
- Mageia 4 Mass Rebuild

* Wed May 29 2013 wally <wally> 0.1.4-1.mga4
+ Revision: 432810
- new version 0.1.4
- add gst1.0 support
- drop upstream applied patch
- workaround one test failing
- clean .spec a bit

* Sat Mar 02 2013 rtp <rtp> 0.1.3-4.mga3
+ Revision: 401071
- disable testsuite on arm (Even with the upstream fix the new dribble test is failing)

* Fri Feb 15 2013 pterjan <pterjan> 0.1.3-3.mga3
+ Revision: 398507
- Add upstream fix for a flaky test

* Sat Jan 12 2013 umeabot <umeabot> 0.1.3-2.mga3
+ Revision: 357859
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 23 2012 wally <wally> 0.1.3-1.mga3
+ Revision: 296906
- new version 0.1.3
- clean some old provides/obsoletes
- fix devel and utils pkg summaries/descriptions

* Thu Jun 28 2012 wally <wally> 0.1.2-1.mga3
+ Revision: 264651
- new version 0.1.2
- clean .spec

* Sat Mar 03 2012 wally <wally> 0.1.1-5.mga2
+ Revision: 217167
- rebuild due to PEM (Package Eating Monster)

* Sat Mar 03 2012 wally <wally> 0.1.1-4.mga2
+ Revision: 217132
- fix libname (change libmajor 1 -> 10)

* Mon Jan 09 2012 dmorgan <dmorgan> 0.1.1-3.mga2
+ Revision: 194040
- Provides libnice-devel

* Tue Nov 08 2011 wally <wally> 0.1.1-2.mga2
+ Revision: 165603
- rebuild for new gupnp-igd

* Thu Sep 22 2011 wally <wally> 0.1.1-1.mga2
+ Revision: 146807
- new version 0.1.1

* Mon Jul 04 2011 anssi <anssi> 0.1.0-4.mga2
+ Revision: 117869
- add more conflicts to ease upgrade

* Fri Apr 15 2011 ahmad <ahmad> 0.1.0-3.mga1
+ Revision: 85907
- fix the file list

* Fri Apr 15 2011 ahmad <ahmad> 0.1.0-2.mga1
+ Revision: 85830
- split gstreamer0.10 library in a separate subpackage to each major upgrades
- disable static build and don't ship .la
- disable rpath (Fedora)
- fix the License tag
- %%doc some more files and move all of them to the -devel subpackage

* Thu Apr 14 2011 dams <dams> 0.1.0-1.mga1
+ Revision: 85006
- Update to 0.1.0

* Sun Jan 23 2011 wally <wally> 0.0.13-2.mga1
+ Revision: 33557
- remove old mdv scriptlets
- split long (>79 chars) lines in description
- tighten requires

  + eandry <eandry>
    - imported package libnice


* Fri Jul 23 2010 Jani Välimaa <wally@mandriva.org> 0.0.13-1mdv2011.0
+ Revision: 557307
- new version 0.0.13
- rebuild for new gupnp-igd

* Sun Jul 11 2010 Emmanuel Andry <eandry@mandriva.org> 0.0.12-1mdv2011.0
+ Revision: 550734
- New version 0.0.12

* Tue Apr 06 2010 Emmanuel Andry <eandry@mandriva.org> 0.0.11-1mdv2010.1
+ Revision: 532333
- New version 0.0.11

* Thu Jan 07 2010 Jani Välimaa <wally@mandriva.org> 0.0.10-2mdv2010.1
+ Revision: 487207
- rebuild for new gupnp-igd

* Thu Nov 12 2009 Frederik Himpe <fhimpe@mandriva.org> 0.0.10-1mdv2010.1
+ Revision: 465208
- update to new version 0.0.10

* Sun Sep 20 2009 Frederik Himpe <fhimpe@mandriva.org> 0.0.9-3mdv2010.0
+ Revision: 445927
- Rebuild for new gupnp

* Tue Aug 25 2009 Lev Givon <lev@mandriva.org> 0.0.9-2mdv2010.0
+ Revision: 421288
- Specify required versions of build dependencies.

* Wed Aug 05 2009 Frederik Himpe <fhimpe@mandriva.org> 0.0.9-1mdv2010.0
+ Revision: 410342
- update to new version 0.0.9

* Tue Jul 28 2009 Emmanuel Andry <eandry@mandriva.org> 0.0.8-3mdv2010.0
+ Revision: 402812
- rename libnice package (containing binaries) to libnice-utils

* Sun Jun 21 2009 Frederik Himpe <fhimpe@mandriva.org> 0.0.8-2mdv2010.0
+ Revision: 387853
- Build with gupnp support
- Use %%configure2_5x instead of %%configure

* Sun Jun 21 2009 Frederik Himpe <fhimpe@mandriva.org> 0.0.8-1mdv2010.0
+ Revision: 387823
- update to new version 0.0.8

* Tue May 26 2009 Frederik Himpe <fhimpe@mandriva.org> 0.0.6-1mdv2010.0
+ Revision: 379979
- update to new version 0.0.6

* Fri Mar 20 2009 Emmanuel Andry <eandry@mandriva.org> 0.0.5-2mdv2009.1
+ Revision: 358234
- move gstreamer .so file in library package

* Fri Mar 06 2009 Emmanuel Andry <eandry@mandriva.org> 0.0.5-1mdv2009.1
+ Revision: 350288
- New version 0.0.5
- disable autoreconf
- update files list

* Wed Jan 07 2009 Emmanuel Andry <eandry@mandriva.org> 0.0.4-1mdv2009.1
+ Revision: 326839
- New version 0.0.4

  + Thierry Vignaud <tv@mandriva.org>
    - fix description

* Sat Nov 29 2008 Emmanuel Andry <eandry@mandriva.org> 0.0.3-1mdv2009.1
+ Revision: 307518
- import libnice


